View Source GoogleApi.MerchantAPI.Reports_v1beta.Model.IssueSeverityPerReportingContext (google_api_merchant_api v0.4.0)
Issue severity per reporting context.
Attributes
-
demotedCountries(type:list(String.t), default:nil) - List of demoted countries in the reporting context, represented in ISO 3166 format. -
disapprovedCountries(type:list(String.t), default:nil) - List of disapproved countries in the reporting context, represented in ISO 3166 format. -
reportingContext(type:String.t, default:nil) - Reporting context the issue applies to.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
Functions
Unwrap a decoded JSON object into its complex fields.